@@ -464,16 +464,9 @@ for details."""
     try:
         sep = arglist.index("--")
     except ValueError:
-        # backwards compatibility: allow three dashes
-        try:
-            sep = arglist.index("---")
-            adtlog.warning(
-                "Using --- to separate virt server arguments is deprecated; use -- instead"
-            )
-        except ValueError:
-            # still allow --help
-            sep = None
-            virt_args = None
+        # still allow --help
+        sep = None
+        virt_args = None
     if sep is not None:
         virt_args = arglist[sep + 1 :]
         arglist = arglist[:sep]
